/**
 * 
 *
 * Software: LGExtract
 * Authors: Matthieu Constant and Elsa Tolone
 *
 * Copyright (C) 2010-2011 Université Paris-Est Marne-la-Vallée
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 *
 */

package fr.umlv.lgextract.actions;

import java.util.List;

import fr.umlv.lgextract.boolexp.BooleanNode;
import fr.umlv.lgextract.exceptions.LGExtractException;
import fr.umlv.lgextract.exceptions.LGExtractNoEntryException;
import fr.umlv.lgextract.lobjects.LGExtractLingObjects;
import fr.umlv.lgextract.lobjects.LingObj;
import fr.umlv.lgextract.table.LGTableEntry;

/**
 * 
 * @author Matthieu Constant
 *
 */

public class CreateAction implements LGAction {

	private LingObj lingobj;
	private BooleanNode boolexp;
	
	public CreateAction(LingObj o,BooleanNode boolexp){
		this.lingobj = o;
		this.boolexp = boolexp;
	}
	
	public void execute(List<LingObj> list, LGTableEntry entry) throws LGExtractException,LGExtractNoEntryException{
		if(!boolexp.eval(entry)) return;
		list.add(this.lingobj);		
	}

	public LingObj getLingObj(){
		return lingobj;
	}
	
	public LGAction clone(LGExtractLingObjects objects) {
		return new CreateAction(objects.getByName(this.getLingObj().getName()),boolexp);
	}
	
	public String toString(){
		return "create "+lingobj.getType()+" "+lingobj.toString()+" if "+ boolexp.toString();
	}	
	
}
